@@ -41,6 +41,11 @@ try:
     from tornado.httpserver import HTTPRequest as TornadoRequest
 except ImportError:
     TornadoRequest = None
+
+try:
+    from bottle import BaseRequest as BottleRequest
+except ImportError:
+    BottleRequest = None
     
 BASE_DATA_HOOK = None
 
@@ -48,7 +53,7 @@ log = logging.getLogger(__name__)
 
 agent_log = None
 
-VERSION = '0.5.8'
+VERSION = '0.5.10'
 DEFAULT_ENDPOINT = 'https://api.rollbar.com/api/1/'
 DEFAULT_TIMEOUT = 3
 
@@ -60,6 +65,7 @@ SETTINGS = {
     'exception_level_filters': [],
     'root': None,  # root path to your code
     'branch': None,  # git branch name
+    'code_version': None,
     'handler': 'thread',  # 'blocking', 'thread' or 'agent'
     'endpoint': DEFAULT_ENDPOINT,
     'timeout': DEFAULT_TIMEOUT,
@@ -392,6 +398,9 @@ def _build_base_data(request, level='error'):
         'uuid': str(uuid.uuid4()),
     }
     
+    if SETTINGS.get('code_version'):
+        data['code_version'] = SETTINGS['code_version']
+    
     if BASE_DATA_HOOK:
         BASE_DATA_HOOK(request, data)
     
@@ -504,6 +513,10 @@ def _build_request_data(request):
     if TornadoRequest and isinstance(request, TornadoRequest):
         return _build_tornado_request_data(request)
 
+    #bottle
+    if BottleRequest and isinstance(request, BottleRequest):
+        return _build_bottle_request_data(request)
+
     return None
 
 
@@ -624,6 +637,17 @@ def _build_tornado_request_data(request):
 
     return request_data
 
+def _build_bottle_request_data(request):
+    request_data = {
+        'url': request.url,
+        'user_ip': request.remote_addr,
+        'headers': dict(request.headers),
+        'method': request.method,
+        'GET': dict(request.query),
+        'POST': dict(request.forms),
+    }
+
+    return request_data
 
 def _build_server_data():
     """
